==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_users.php <==
<?php
class Users extends Admin {
	public function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function update_users() {
		// empty form
		$formValues = array();
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if (isset($value['delete']) && $id != 1) {
				$query = "DELETE FROM ".USERS." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERPAGES." WHERE USERID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".ARTICLES." WHERE USERID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".PAGES." WHERE USERID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "";
		return $result;
	}
	public function list_users($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
		$owners = array();
		$query = $this->q("SELECT ID,USERNAME FROM ".USERS);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$owners[$line['ID']] = $line['USERNAME'];
		}
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 1 AND".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 2 AND ".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid']." AND ".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 1 ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 2 ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$modified = (empty($_POST))?null:$this->tr->w(", (some values have been modified !)");
		$usersListTitle = $this->h->h3($this->tr->w("users list").$modified);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=users");
		
		$usersSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("delete selected")));
		$usersList = "";
		while ( $line = @mysql_fetch_assoc($query) ) {
			$modify = $this->h->ahref("admin.php?action=modify_user&amp;user=".$line['ID'],$this->tr->w("modify"));
			$view = $this->h->ahref("index.php?user=".$line['ID'],$this->tr->w("view"),"target=_blank");
			$login = "(".$line['LOGIN'].") ";
			$level = $this->tr->w("level-").$line['USERLEVEL'];
			$name = "\"".strip_tags($line['USERNAME'])."\"";
			$owner = $this->tr->w("{by-").$owners[$line['USEROWNER']]."}";
			$delete = ($line['ID'] != 1)?$this->tr->wsp("delete").$this->h->input("checkbox","delete_".$line['ID'],"on"):$this->h->span($this->tr->w("protected"),"style=\"color:red\"");
			$content = $modify." ".$view." ".$delete." | ".$level." | ".$this->h->span($name,"style=\"color:green\"")." ".$login." ".$owner;
			$usersList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$usersList = $usersSubmit.$usersList.$nextPages.$usersSubmit;
		$result = $usersListTitle.$searchForm.$this->h->form($usersList,"users","post","admin.php?action=users&amp;pg=".$this->pagePos);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS;
		$queryLevel2 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS." WHERE USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=users");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_users.php <==
<?php
class Users extends Admin {
	public function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function update_users() {
		// empty form
		$formValues = array();
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if (isset($value['delete']) && $id != 1) { // nevers delete admin
				$query = "DELETE FROM ".USERS." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERPAGES." WHERE USERID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".ARTICLES." WHERE USERID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".PAGES." WHERE USERID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "";
		return $result;
	}
	public function list_users($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
        if (isset($_GET['ownerFilter'])){
            $_SESSION['admin_users_filter'] = $_GET['ownerFilter'];
        }
        if (isset($_POST['reset'])){
            $_SESSION['admin_users_filter'] = "";
        }
		$owners = array();
		$query = $this->q("SELECT ID,USERNAME FROM ".USERS);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$owners[$line['ID']] = $line['USERNAME'];
		}
		if (isset($_POST['search'])) {
            $queryLevel0 = 	"SELECT * FROM ".USERS." WHERE ".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel1 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 1 AND".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 2 AND ".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid']." AND ".
							"MATCH(".USERS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
        } elseif (isset($_SESSION['admin_users_filter']) && $_SESSION['admin_users_filter'] != "") {
            $queryLevel0 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['admin_users_filter']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel1 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 1 AND USEROWNER = ".$_SESSION['admin_users_filter']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 2 AND USEROWNER = ".$_SESSION['admin_users_filter']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
            $queryLevel0 = 	"SELECT * FROM ".USERS." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel1 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 1 ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT * FROM ".USERS." WHERE USERLEVEL > 2 ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT * FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid']." ORDER BY USERNAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		$queries = array("",$queryLevel0,$queryLevel1,$queryLevel2,$queryLevel3);
        // print $queries[$_SESSION['level']];
		$query = $this->q($queries[$_SESSION['level']]);
		$modified = (empty($_POST))?null:$this->tr->w(", (some values have been modified !)");
		$usersListTitle = $this->h->h3($this->tr->w("users list").$modified);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=users");
        
        $resetForm = $this->h->p($this->h->input("submit","",$this->tr->w("no filters")).$this->h->input("hidden","reset",1));
		$resetForm = $this->h->form($resetForm,"reset","post","admin.php?action=users");
		
		$usersSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("delete selected")));
		$usersList = "";
		while ( $line = @mysql_fetch_assoc($query) ) {
			$modify = $this->h->ahref("admin.php?action=modify_user&amp;user=".$line['ID'],$this->tr->w("modify"));
			$view = $this->h->ahref("index.php?user=".$line['ID'],$this->tr->w("view"),"target=_blank");
			$login = "(".$line['LOGIN'].") ";
			$level = $this->tr->w("level-").$line['USERLEVEL'];
			$name = "\"".strip_tags($line['USERNAME'])."\"";
			$owner = $this->tr->w("by-").$this->h->ahref("admin.php?action=users&amp;ownerFilter=".$line['USEROWNER'],$owners[$line['USEROWNER']]);
			$delete = ($line['ID'] != 1)?$this->tr->wsp("delete").$this->h->input("checkbox","delete_".$line['ID'],"on"):$this->h->span($this->tr->w("protected"),"style=\"color:red\"");
			$content = $modify." ".$view." ".$delete." | ".$level." | ".$this->h->span($name,"style=\"color:green\"")." ".$login." ".$owner;
			$usersList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$usersList = $usersSubmit.$usersList.$nextPages.$usersSubmit;
		$result = $usersListTitle.$searchForm.$resetForm.$this->h->form($usersList,"users","post","admin.php?action=users&amp;pg=".$this->pagePos);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS;
		$queryLevel2 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS." WHERE USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".USERS." WHERE USEROWNER = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=users");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>
